@@ -105,8 +105,8 @@ def Scale(factor):
 def Rotate(angle):
     return Affine(
         numpy.array([
-            [cos(angle), sin(angle), 0],
-            [-sin(angle), cos(angle), 0]
+            [math.cos(angle), math.sin(angle), 0],
+            [-math.sin(angle), math.cos(angle), 0]
         ])
     )
 
